# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator 1.0.1.0
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SlotSwapConfiguration(Model):
    _attribute_map = {
        'slot_name': {'key': 'slotName', 'type': 'str'},
    }

    def __init__(self, slot_name=None):
        self.slot_name = slot_name
