# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator 1.0.1.0
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AuthorizationInfo(Model):
    _attribute_map = {
        'scheme': {'key': 'scheme', 'type': 'str'},
        'parameters': {'key': 'parameters', 'type': 'AuthorizationInfoParameters'},
    }

    def __init__(self, scheme=None, parameters=None):
        self.scheme = scheme
        self.parameters = parameters
