# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator 1.0.1.0
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ProvisioningConfiguration(Model):
    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'source': {'key': 'source', 'type': 'ProvisioningConfigurationSource'},
        'targets': {'key': 'targets', 'type': '[ProvisioningConfigurationTarget]'},
        'ci_configuration': {'key': 'ciConfiguration', 'type': 'CiConfiguration'},
    }

    def __init__(self, id=None, source=None, targets=None, ci_configuration=None):
        self.id = id
        self.source = source
        self.targets = targets
        self.ci_configuration = ci_configuration
