# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator 1.0.1.0
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from .vsts_info_provider import VstsInfoProvider
from .version import VERSION

__all__ = ['VstsInfoProvider']

__version__ = VERSION

