# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator 1.0.1.0
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from .collection import Collection
from .name_availability import NameAvailability
from .region_details import RegionDetails
from .regions import Regions

__all__ = [
    'Collection',
    'NameAvailability',
    'RegionDetails',
    'Regions',
]