# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator 1.0.1.0
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ProvisioningConfigurationTarget(Model):
    _attribute_map = {
        'provider': {'key': 'provider', 'type': 'str'},
        'target_type': {'key': 'type', 'type': 'str'},
        'environment_type': {'key': 'environmentType', 'type': 'str'},
        'friendly_name': {'key': 'friendlyName', 'type': 'str'},
        'subscription_id': {'key': 'subscriptionId', 'type': 'str'},
        'subscription_name': {'key': 'subscriptionName', 'type': 'str'},
        'tenant_id': {'key': 'tenantId', 'type': 'str'},
        'resource_identifier': {'key': 'resourceIdentifier', 'type': 'str'},
        'resource_group_name': {'key': 'resourceGroupName', 'type': 'str'},
        'location': {'key': 'location', 'type': 'str'},
        'authorization_info': {'key': 'authorizationInfo', 'type': 'AuthorizationInfo'},
        'slot_swap_configuration': {'key': 'slotSwapConfiguration', 'type': 'SlotSwapConfiguration'},
        'create_options': {'key': 'createOptions', 'type': 'CreateOptions'}
    }

    def __init__(self, provider=None, target_type=None, environment_type=None, friendly_name=None, subscription_id=None, subscription_name=None, tenant_id=None,
                 resource_identifier=None, resource_group_name=None, location=None, authorization_info=None,
                 slot_swap_configuration=None, create_options=None):
        self.provider = provider
        self.target_type = target_type
        self.environment_type = environment_type
        self.friendly_name = friendly_name
        self.subscription_id = subscription_id
        self.subscription_name = subscription_name
        self.tenant_id = tenant_id
        self.resource_identifier = resource_identifier
        self.resource_group_name = resource_group_name
        self.location = location
        self.authorization_info = authorization_info
        self.slot_swap_configuration = slot_swap_configuration
        self.create_options = create_options