# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator 1.0.1.0
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CiConfiguration(Model):
    _attribute_map = {
        'project': {'key': 'project', 'type': 'CiArtifact'},
        'build_definition': {'key': 'buildDefinition', 'type': 'CiArtifact'},
        'release_definition': {'key': 'releaseDefinition', 'type': 'CiArtifact'},
        'result': {'key': 'result', 'type': 'CiResult'},
    }

    def __init__(self, project=None, build_definition=None, release_definition=None, result=None):
        self.project = project
        self.build_definition = build_definition
        self.release_definition = release_definition
        self.result = result
