# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator 1.0.1.0
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TeamProjectInfo(Model):
    """TeamProjectInfo.

    :param id:
    :type id: str
    :param name:
    :type name: str
    :param url:
    :type url: str
    :param state:
    :type state: int
    :param revision:
    :type revision: int
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'url': {'key': 'url', 'type': 'str'},
        'state': {'key': 'state', 'type': 'int'},
        'revision': {'key': 'revision', 'type': 'int'},
    }

    def __init__(self, id=None, name=None, url=None, state=None, revision=None):
        self.id = id
        self.name = name
        self.url = url
        self.state = state
        self.revision = revision
