# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator 1.0.1.0
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from .authorization_info import AuthorizationInfo
from .authorization_info_parameters import AuthorizationInfoParameters
from .build_configuration import BuildConfiguration
from .ci_artifact import CiArtifact
from .ci_configuration import CiConfiguration
from .ci_result import CiResult
from .provisioning_configuration import ProvisioningConfiguration
from .provisioning_configuration_source import ProvisioningConfigurationSource
from .provisioning_configuration_target import ProvisioningConfigurationTarget
from .slot_swap_configuration import SlotSwapConfiguration
from .source_repository import SourceRepository
from .create_options import CreateOptions

__all__ = [
    'AuthorizationInfo',
    'AuthorizationInfoParameters',
    'BuildConfiguration',
    'CiArtifact',
    'CiConfiguration',
    'CiResult',
    'ProvisioningConfiguration',
    'ProvisioningConfigurationSource',
    'ProvisioningConfigurationTarget',
    'SlotSwapConfiguration',
    'SourceRepository',
    'CreateOptions',
]
