# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator 1.0.1.0
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ProvisioningConfigurationSource(Model):
    _attribute_map = {
        'type': {'key': 'type', 'type': 'str'},
        'repository': {'key': 'repository', 'type': 'SourceRepository'},
        'build_configuration': {'key': 'buildConfiguration', 'type': 'BuildConfiguration'},
    }

    def __init__(self, type=None, repository=None, build_configuration=None):
        self.type = type
        self.repository = repository
        self.build_configuration = build_configuration
