# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator 1.0.1.0
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class VstsInfo(Model):
    """VstsInfo.

    :param server_url:
    :type server_url: str
    :param collection_info:
    :type collection_info: object
    :param repository_info:
    :type repository_info: object
    """

    _attribute_map = {
        'server_url': {'key': 'serverUrl', 'type': 'str'},
        'collection_info': {'key': 'collection', 'type': 'CollectionInfo'},
        'repository_info': {'key': 'repository', 'type': 'RepositoryInfo'},
    }

    def __init__(self, server_url=None, collection_info=None, repository_info=None):
        self.server_url = server_url
        self.collection_info = collection_info
        self.repository_info = repository_info
